@@ -2,9 +2,9 @@ package Win32::IE::Link;
 use strict;
 use warnings;
 
-# $Id: Link.pm 401 2005-08-26 11:55:50Z abeltje $
+# $Id: Link.pm 223 2005-01-03 22:30:25Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.005';
+$VERSION = '0.002';
 
 =head1 NAME Win32::IE::Link
 
@@ -55,52 +55,13 @@ sub new {
     bless \( my $self = shift ), $class;
 }
 
-=head2 $link->attrs
-
-Returns hash ref of all the attributes and attribute values in the tag.
-
-=cut
-
-sub attrs {
-    my $self = ${ $_[0] };
-
-    my $attrs = { };
-    for ( my $ i = 0; $i < $self->attributes->length; $i++ ) {
-        my $attr = $self->attributes( $i );
-        $attrs->{ $attr->nodeName } = $attr->nodeValue;
-    }
-
-    return $attrs;
-}
-
 =head2 $link->url
 
 Returns the url from the link.
 
-B<NOTE>: The IE automation object only shows the interpreted results
-in the attributs collection, so url() and url_abs() will be the same.
-
 =cut
 
 sub url {
-    my $self = $_[0];
-    my $link = $$self;
-
-    my $attrs = $self->attrs;
-    if ( $link->{tagName} =~ /^I?FRAME$/ ) {
-        return defined $attrs->{src} ? $attrs->{src} : $link->{src};
-    } else {
-        return defined $attrs->{href} ? $attrs->{href} : $link->{href};
-    }
-}
-
-=head2 $link->url_abs
-
-Returns the url from the link.
-
-=cut
-
-sub url_abs {
     my $self = ${ $_[0] };
 
     if ( $self->{tagName} =~ /^I?FRAME$/ ) {
@@ -118,9 +79,7 @@ Text of the link.
 
 sub text {
     my $self = ${ $_[0] };
-    return defined $self->{innerText}
-        ? $self->{innerText}
-        : defined $self->{innerHTML} ? $self->innerHTML : '';
+    return defined $self->{innerHTML} ? $self->innerHTML : '';
 }
 
 =head2 $link->name
@@ -146,17 +105,6 @@ sub tag {
     return $self->{tagName};
 }
 
-=head2 $link->click
-
-The IE link object supports its own click() method, so make it available.
-
-=cut
-
-sub click {
-    my $self = ${ $_[0] };
-    $self->fireEvent( 'onclick' );
-}
-
 1;
 
 =head1 COPYRIGHT AND LICENSE
